@@ -3,7 +3,7 @@ use std::time::Duration;
 /// The result of measurement.
 #[derive(Debug, Clone)]
 pub struct MeasureResult {
-    pub(crate) times: u128,
+    pub(crate) times:         u128,
     pub(crate) total_elapsed: Duration,
 }
 
@@ -13,16 +13,14 @@ impl MeasureResult {
     #[inline]
     pub(crate) fn new(elapsed: Duration) -> MeasureResult {
         MeasureResult {
-            times: 1,
-            total_elapsed: elapsed,
+            times: 1, total_elapsed: elapsed
         }
     }
 
     #[inline]
     pub(crate) fn empty() -> MeasureResult {
         MeasureResult {
-            times: 0,
-            total_elapsed: Duration::from_secs(0),
+            times: 0, total_elapsed: Duration::from_secs(0)
         }
     }
 
